import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import { createUseStyles } from 'react-jss';
import FormTemplate from '@data-driven-forms/common/form-template';
import { Button } from "@blueprintjs/core/lib/esm/components/button/buttons.js";
import { H1 } from "@blueprintjs/core/lib/esm/components/html/html.js";
import { H2 } from "@blueprintjs/core/lib/esm/components/html/html.js";
import BlueprintContext from '../blueprint-context/blueprint-context';

var Form = function Form(_ref) {
  var children = _ref.children,
      props = _objectWithoutProperties(_ref, ["children"]);

  return /*#__PURE__*/React.createElement("form", _extends({
    noValidate: true
  }, props, {
    style: {
      display: 'grid'
    }
  }), children);
};

Form.propTypes = {
  children: PropTypes.node
};
var useStyles = createUseStyles({
  buttonGroup: {
    marginTop: 16,
    '& button:not(:first-child)': {
      marginLeft: 8
    }
  }
});

var ButtonGroup = function ButtonGroup(_ref2) {
  var children = _ref2.children,
      props = _objectWithoutProperties(_ref2, ["children"]);

  var _useStyles = useStyles(),
      buttonGroup = _useStyles.buttonGroup;

  return /*#__PURE__*/React.createElement("div", _extends({
    className: buttonGroup
  }, props), children);
};

ButtonGroup.propTypes = {
  children: PropTypes.node
};

var Title = function Title(_ref3) {
  var children = _ref3.children,
      props = _objectWithoutProperties(_ref3, ["children"]);

  return /*#__PURE__*/React.createElement(H1, props, children);
};

Title.propTypes = {
  children: PropTypes.node
};

var Description = function Description(_ref4) {
  var children = _ref4.children,
      props = _objectWithoutProperties(_ref4, ["children"]);

  return /*#__PURE__*/React.createElement(H2, props, children);
};

Description.propTypes = {
  children: PropTypes.node
};

var InnerButton = function InnerButton(_ref5) {
  var label = _ref5.label,
      buttonType = _ref5.buttonType,
      props = _objectWithoutProperties(_ref5, ["label", "buttonType"]);

  return /*#__PURE__*/React.createElement(Button, _extends({
    intent: buttonType === 'submit' ? 'success' : ''
  }, props), label);
};

InnerButton.propTypes = {
  children: PropTypes.node,
  label: PropTypes.node,
  buttonType: PropTypes.string
};

var BlueprintFormTemplate = function BlueprintFormTemplate(_ref6) {
  var requiredLabelInfo = _ref6.requiredLabelInfo,
      props = _objectWithoutProperties(_ref6, ["requiredLabelInfo"]);

  return /*#__PURE__*/React.createElement(BlueprintContext.Provider, {
    value: {
      required: requiredLabelInfo || /*#__PURE__*/React.createElement("span", {
        className: "bp3-text-muted"
      }, "(required)")
    }
  }, /*#__PURE__*/React.createElement(FormTemplate, _extends({
    FormWrapper: Form,
    Button: InnerButton,
    ButtonGroup: ButtonGroup,
    Title: Title,
    Description: Description
  }, props)));
};

BlueprintFormTemplate.propTypes = {
  requiredLabelInfo: PropTypes.node
};
export default BlueprintFormTemplate;